# Hedra plugin for LiveKit Agents

Support for avatar generation and animation with [Hedra](https://hedra.ai/).

See [https://docs.livekit.io/agents/integrations/avatar/hedra/](https://docs.livekit.io/agents/integrations/avatar/hedra/) for more information.

## Installation

```bash
pip install livekit-plugins-hedra
```

## Pre-requisites

You'll need an API key from Hedra. It can be set as an environment variable: `HEDRA_API_KEY`